@@ -4,7 +4,7 @@ use 5.024;
 use warnings;
 use utf8;
 
-our $VERSION = "0.9903";
+our $VERSION = "0.9904";
 
 =encoding utf-8
 
@@ -45,7 +45,7 @@ B<greple> B<-Mcharcode> [ I<module option> ] -- [ I<command option> ] ...
 
 =head1 VERSION
 
-Version 0.9903
+Version 0.9904
 
 =head1 DESCRIPTION
 
@@ -454,3 +454,6 @@ option --ansicode-each \
 
 option --ansicode-seq \
     --visible-option -E '(?:ANSI-CSI)+'
+
+option --charcode::config --prologue &__PACKAGE__::config($<shift>)
+option --config --charcode::config
